@@ -116,7 +116,7 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
+#define HAVE_HIST_ENTRY 1
 /* #undef USE_LIBEDIT_INTERFACE */
 #define USE_NEW_READLINE_INTERFACE 1
 
@@ -196,6 +196,7 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
+#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -278,10 +279,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define HAVE_LONG 1
@@ -296,7 +297,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -334,7 +335,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -395,8 +396,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "sparc64"
-#define DEFAULT_MACHINE "sparc64"
+#define MACHINE_TYPE "earmv7hf"
+#define DEFAULT_MACHINE "earmv7hf"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -532,16 +533,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 19
+#define MYSQL_VERSION_PATCH 20
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.19"
+#define PACKAGE_STRING "MySQL Server 10.6.20"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.19"
-#define VERSION "10.6.19"
+#define PACKAGE_VERSION "10.6.20"
+#define VERSION "10.6.20"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
